@@ -25,6 +25,10 @@ class Gitalist::Git::CollectionOfRepositories::FromDirectory
         return $path;
     }
 
+    method _get_repo_from_name (NonEmptySimpleStr $name) {
+        return Gitalist::Git::Repository->new($self->_get_path_for_repository_name($name));
+    }
+
     ## Builders
     method _build_repositories {
         my $dh = $self->repo_dir->open || die "Could not open repo_dir";
